
<template>
  <view-grid
    ref="grid"
    :columns="columns"
    :detail="detail"
    :editFormFields="editFormFields"
    :editFormOptions="editFormOptions"
    :searchFormFields="searchFormFields"
    :searchFormOptions="searchFormOptions"
    :table="table"
    :extend="extend"
  >
  </view-grid>
</template>
    <script>
import extend from "@/extension/outbound/outStockLockInfo.js";
import { ref, defineComponent } from "vue";
export default defineComponent({
  setup() {
    const table = ref({
      key: "id",
      footer: "Foots",
      cnName: "出库详情",
      name: "outStockLockInfo",
      url: "/OutStockLockInfo/",
      sortName: "id",
    });
    const editFormFields = ref({
      orderType: "",
      orderNo:"",
      upperOrderNo: "",
      orderStatus: "",
      remark: "",
      warehouseId:""
    });
    const editFormOptions = ref([
      [
        {
          title: "单据类型",
          required: true,
          field: "orderType",
          type: "select",
          dataKey: "outOrderType",
          data: [],
        },
        {
        field: "orderNo",
        title: "单据编号",
        type: "string",
        readonly:true
      },
        {
          title: "上游单据编号",
          field: "upperOrderNo",
          type: "string",
        },
        {
          title: "单据状态",
          field: "orderStatus",
          type: "select",
          dataKey: "inboundState",
          data: [],
          readonly: true,
        },
        {
          title: "仓库",
          field: "warehouseId",
          type: "select",
          dataKey: "warehouses",
          data: [],
          required: true,
        },
        {
          title: "备注",
          field: "remark",
          type: "textarea",
        },
      ],
    ]);
    const searchFormFields = ref({
      orderNo: "",
      upperOrderNo: "",
      orderType: "",
      orderStatus: "",
      createType: "",
      creater: "",
      createDate: "",
    });
    const searchFormOptions = ref([
      [
        { title: "单据编号", field: "orderNo", type: "like" },
        { title: "批次号", field: "batchNo", type: "like" },
        { title: "物料编号", field: "materielCode", type: "like" },
        {
          title: "单据类型",
          field: "orderType",
          type: "select",
          dataKey: "outOrderType",
          data: [],
        },
        
      ],
      [
        {title: "物料名称",field: "materielName",type: "like",},
        { title: "单据数量", field: "orderQuantity", type: "like" },
        { title: "原始库存量", field: "originalQuantity", type: "like" },
        { title: "分配库存量", field: "assignQuantity", type: "like" },
      ],
      [
        {title: "货位编号",field: "locationCode",type: "like",},
        { title: "托盘编号", field: "palletCode", type: "like" },
        { title: "任务号", field: "taskNum", type: "like" },
        { title: "状态", field: "status", type: "select",dataKey:"outLockStockStatusEnum", data:[]},
      ],
    ]);
    const columns = ref([
      {
        field: "id",
        title: "Id",
        type: "int",
        width: 90,
        hidden: true,
        readonly: true,
        require: true,
        align: "left",
      },
      {
        field: "orderNo",
        title: "单据编号",
        type: "string",
        width: 150,
        align: "left",
        
      },
      {
        field: "batchNo",
        title: "批次号",
        type: "string",
        width: 160,
        align: "left",
        // link: true,
      },
      {
        field: "materielCode",
        title: "物料编号",
        type: "string",
        width: 160,
        align: "left",
      },
      {
        field: "orderType",
        title: "单据类型",
        type: "string",
        width: 150,
        align: "left",
        bind: { key: "outOrderType", data: [] },
      },
      {
        field: "materielName",
        title: "物料名称",
        type: "string",
        width: 120,
        align: "left",
        
      },
      {
        field: "orderQuantity",
        title: "单据数量",
        type: "string",
        width: 120,
        align: "left"
      },
      {
        field: "originalQuantity",
        title: "原始库存量",
        type: "string",
        width: 90,
        align: "left",
      },
      {
        field: "assignQuantity",
        title: "分配出库量",
        type: "string",
        width: 90,
        align: "left",
      },
      {
        field: "locationCode",
        title: "货位编号",
        type: "datetime",
        width: 160,
        align: "left",
      },
      {
        field: "palletCode",
        title: "托盘编号",
        type: "string",
        width: 100,
        align: "left",
      },
      {
        field: "unit",
        title: "单位",
        type: "datetime",
        width: 160,
        align: "left",
      },
      {
        field: "productionDate",
        title: "生产日期",
        type: "string",
        width: 160,
        align: "left",
      },
      {
        field: "effectiveDate",
        title: "有效期",
        type: "string",
        width: 160,
        align: "left",
      },
      {
        field: "taskNum",
        title: "任务号",
        type: "string",
        width: 100,
        align: "left",
      },
      {
        field: "status",
        title: "状态",
        type: "string",
        width: 100,
        align: "left",
        bind:{key:"outLockStockStatusEnum", data: []}
      },
    ]);
    const detail = ref({
      cnName: "#detailCnName",
      columns: [],
      sortName: "",
      key: "",
    });
    return {
      table,
      extend,
      editFormFields,
      editFormOptions,
      searchFormFields,
      searchFormOptions,
      columns,
      detail,
    };
  },
});
</script>
    